The Lands Chamber is responsible for handling appeals against decisions made by First-Tier Tribunal (Property Chamber); Residential Property Tribunal in Wales and Leasehold Valuation Tribunal in Wales.

They are also responsible for handling applications for cases about a decision about rates made by the Valuation Tribunal in England or Wales; compensation for the compulsory purchase of land; discharge or modification of land affected by a ‘restrictive covenant’; compensation for the effect on land affected by public works; a tree preservation order; compensation for damage to land damaged by subsidence from mining; the valuation of land or buildings for Capital Gains Tax or Inheritance Tax purposes; a ‘right to light’ dispute; compensation for blighted land and Electronic Communication Code - disputes involving masts and other telecommunications equipment on land.

This tribunal began to regularly transfer decisions to The National Archives in 2022. The oldest decision from this tribunal included in Find Case Law is from {start_year}.

You can read more about it on the Lands Chamber on the [HM Courts and Tribunals Service website](https://www.gov.uk/courts-tribunals/upper-tribunal-lands-chamber){target="\_blank"}.
